==> igniteui-react-layouts-18.7.3.tgz: package/esm2015/lib/igr-tool-action-checkbox-list.js <==
import { IgrLayoutSelectedKeysCollection } from "./igr-layout-selected-keys-collection";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionCheckboxList } from "./ToolActionCheckboxList";
import { LayoutSelectedKeysCollection as LayoutSelectedKeysCollection_internal } from "./LayoutSelectedKeysCollection";
import { LayoutPrimaryKeyValue } from "./LayoutPrimaryKeyValue";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
export class IgrToolActionCheckboxList extends IgrToolAction {
    createImplementation() {
        return new ToolActionCheckboxList();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._selectedKeys = null;
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get dataSource() {
        return this.i.itemsSource;
    }
    set dataSource(v) {
        this.i.itemsSource = v;
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get selectedMemberPath() {
        return this.i.hr;
    }
    set selectedMemberPath(v) {
        this.i.hr = v;
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get dataMemberPath() {
        return this.i.hm;
    }
    set dataMemberPath(v) {
        this.i.hm = v;
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get primaryKey() {
        return this.i.hb;
    }
    set primaryKey(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.hb = v;
    }
    /**
    
    */
    get selectedKeys() {
        if (this._selectedKeys === null) {
            let coll = new IgrLayoutSelectedKeysCollection();
            let innerColl = this.i.hc;
            if (!innerColl) {
                innerColl = new LayoutSelectedKeysCollection_internal();
            }
            this._selectedKeys = coll._fromInner(innerColl);
            this.i.hc = innerColl;
        }
        return this._selectedKeys;
    }
    set selectedKeys(v) {
        if (this._selectedKeys !== null) {
            this._selectedKeys._setSyncTarget(null);
            this._selectedKeys = null;
        }
        let coll = new IgrLayoutSelectedKeysCollection();
        this._selectedKeys = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(LayoutPrimaryKeyValue.$type);
        let innerColl = this.i.hc;
        if (!innerColl) {
            innerColl = new LayoutSelectedKeysCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._selectedKeys._setSyncTarget(syncColl);
        this.i.hc = innerColl;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.selectedKeys != null && this.selectedKeys.findByName && this.selectedKeys.findByName(name)) {
            return this.selectedKeys.findByName(name);
        }
        return null;
    }
}

==> igniteui-react-layouts-18.7.5.tgz: package/esm2015/lib/igr-tool-action-checkbox-list.js <==
import { IgrLayoutSelectedKeysCollection } from "./igr-layout-selected-keys-collection";
import { ToolActionCheckboxListIndexType_$type } from "./ToolActionCheckboxListIndexType";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionCheckboxList } from "./ToolActionCheckboxList";
import { ensureBool, ensureEnum } from "igniteui-react-core";
import { LayoutSelectedKeysCollection as LayoutSelectedKeysCollection_internal } from "./LayoutSelectedKeysCollection";
import { LayoutPrimaryKeyValue } from "./LayoutPrimaryKeyValue";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
export class IgrToolActionCheckboxList extends IgrToolAction {
    createImplementation() {
        return new ToolActionCheckboxList();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
        this._selectedKeys = null;
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get dataSource() {
        return this.i.itemsSource;
    }
    set dataSource(v) {
        this.i.itemsSource = v;
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get selectedMemberPath() {
        return this.i.ho;
    }
    set selectedMemberPath(v) {
        this.i.ho = v;
    }
    /**
     * Gets or sets if the select all row is shown.
    */
    get showSelectAll() {
        return this.i.hd;
    }
    set showSelectAll(v) {
        this.i.hd = ensureBool(v);
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get dataMemberPath() {
        return this.i.hi;
    }
    set dataMemberPath(v) {
        this.i.hi = v;
    }
    /**
     * Gets or sets if the tool action is checked.
    */
    get primaryKey() {
        return this.i.g7;
    }
    set primaryKey(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.g7 = v;
    }
    /**
    
    */
    get selectedKeys() {
        if (this._selectedKeys === null) {
            let coll = new IgrLayoutSelectedKeysCollection();
            let innerColl = this.i.g8;
            if (!innerColl) {
                innerColl = new LayoutSelectedKeysCollection_internal();
            }
            this._selectedKeys = coll._fromInner(innerColl);
            this.i.g8 = innerColl;
        }
        return this._selectedKeys;
    }
    set selectedKeys(v) {
        if (this._selectedKeys !== null) {
            this._selectedKeys._setSyncTarget(null);
            this._selectedKeys = null;
        }
        let coll = new IgrLayoutSelectedKeysCollection();
        this._selectedKeys = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(LayoutPrimaryKeyValue.$type);
        let innerColl = this.i.g8;
        if (!innerColl) {
            innerColl = new LayoutSelectedKeysCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._selectedKeys._setSyncTarget(syncColl);
        this.i.g8 = innerColl;
    }
    /**
    
    */
    get indexType() {
        return this.i.g9;
    }
    set indexType(v) {
        this.i.g9 = ensureEnum(ToolActionCheckboxListIndexType_$type, v);
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.selectedKeys != null && this.selectedKeys.findByName && this.selectedKeys.findByName(name)) {
            return this.selectedKeys.findByName(name);
        }
        return null;
    }
}
